LocalHnswItem<V> class

Constructors

LocalHnswItem({required V item, required List<double> vector})

Properties

hashCode int
The hash code for this object.
no setterinherited
item → V
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vector List<double>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited